#include<stdio.h>
#include<math.h>

#define NPR 20
#define SMOOTH_WIN 7 
#define NSMOOTH (SMOOTH_WIN-1)/2

#define MAXTP 201
#define TPOSC "is.dat"
#define FLAGF "startd.dat"  

#define BIGNUM 1e100

int main(void){
  int i,j,k,jj,ntp,id[MAXTP],flag[MAXTP];
  double sema[MAXTP],ecc[MAXTP],inc[MAXTP],aper[MAXTP],node[MAXTP],mano[MAXTP];
  double dist[MAXTP],time[NPR+1];
  double minact[MAXTP][NPR+1],maxact[MAXTP][NPR+1],aveact[MAXTP][NPR+1];
  double minang[MAXTP][NPR+1],maxang[MAXTP][NPR+1],aveang[MAXTP][NPR+1];
  double minminact[MAXTP][3],maxmaxact[MAXTP][3],aveaveact[MAXTP][3];
  double minminang[MAXTP][3],maxmaxang[MAXTP][3],aveaveang[MAXTP][3];
  double dmaxact[MAXTP],dminact[MAXTP],daveact[MAXTP];
  double dmaxang[MAXTP],dminang[MAXTP],daveang[MAXTP];
  double ampact[MAXTP],ampang[MAXTP];
  double avedact,avedang;
  double dbuf;
  FILE *fp;

  /* READS THE NUMBER OF TP AND THEIR INITIAL CONDITIONS */ 
  fp=fopen(TPOSC,"r");
  fscanf(fp,"%d",&ntp);
  for(i=1;i<=ntp+1;i++) fscanf(fp,"%lg",&dbuf);
  for(i=1;i<=ntp;i++)
    fscanf(fp,"%lg %lg %lg %lg %lg %lg",
	   &sema[i],&ecc[i],&inc[i],&aper[i],&node[i],&mano[i]);
  fclose(fp);

  /* READS THE FLAG FILE */
  fp=fopen(FLAGF,"r");
  for(i=1;i<=ntp;i++)
    fscanf(fp,"%d %lg %d",&id[i],&dist[i],&flag[i]);
  fclose(fp);

  /* READS THE PROPER ELEMENTS */
  for(j=1;j<=NPR;j++){
    scanf("%lg",&time[j]);   
    for(i=1;i<=ntp;i++){
	scanf("%d %lg %lg %lg %lg %lg %lg",
	      &id[i],&minact[i][j],&maxact[i][j],&aveact[i][j],
	      &minang[i][j],&maxang[i][j],&aveang[i][j]);
    }
  }

  /* COMPUTES MIN, MAX and AVERAGE */
  for(i=1;i<=ntp;i++){
    for(k=1;k<=2;k++){
      jj = (k-1)*NPR/2; 
      
      minminact[i][k] = BIGNUM;
      maxmaxact[i][k] = -BIGNUM;
      aveaveact[i][k] = 0;
      minminang[i][k] = BIGNUM;
      maxmaxang[i][k] = -BIGNUM;
      aveaveang[i][k] = 0;
    
      for(j=jj+1;j<=jj+NPR/2;j++){
	if( minact[i][j] < minminact[i][k] ) minminact[i][k] = minact[i][j];
	if( maxact[i][j] > maxmaxact[i][k] ) maxmaxact[i][k] = maxact[i][j];
	if( minang[i][j] < minminang[i][k] ) minminang[i][k] = minang[i][j];
	if( maxang[i][j] > maxmaxang[i][k] ) maxmaxang[i][k] = maxang[i][j];
	aveaveact[i][k] += aveact[i][j];
	aveaveang[i][k] += aveang[i][j];
      }
      aveaveact[i][k] = aveaveact[i][k] / (NPR / 2);
      aveaveang[i][k] = aveaveang[i][k] / (NPR / 2);
    }
  }


  /* COMPUTES THE CHANGES OF PROPER ELEMENTS */
  for(i=1;i<=ntp;i++)
    if(flag[i] != 0){
      dmaxact[i] = maxmaxact[i][2] - maxmaxact[i][1];
      dminact[i] = minminact[i][2] - minminact[i][1];
      daveact[i] = aveaveact[i][2] - aveaveact[i][1];
      dmaxang[i] = maxmaxang[i][2] - maxmaxang[i][1];
      dminang[i] = minminang[i][2] - minminang[i][1];
      daveang[i] = aveaveang[i][2] - aveaveang[i][1];
    } else { 
      dmaxact[i] = BIGNUM;
      dminact[i] = BIGNUM;
      daveact[i] = BIGNUM;
      dmaxang[i] = BIGNUM;
      dminang[i] = BIGNUM;
      daveang[i] = BIGNUM;
    }

  /* COMPUTE THE FULL AMPLITUDES */
  for(i=1;i<=ntp;i++){
    ampact[i] = maxmaxact[i][1] - minminact[i][1];
    ampang[i] = maxmaxang[i][1] - minminang[i][1];
  }

  /* THE CHANGE IS NOT SMOOTHED ON MARGINS */ 
  for(i=1;i<=NSMOOTH;i++)
    printf("%d %d %lg %lg %lg %lg %lg %lg %lg\n",
	   id[i],flag[i],sema[i],ecc[i],inc[i],ampact[i],
	   log10(fabs(dmaxact[i])),ampang[i],log10(fabs(dmaxang[i])));

  /* SMOOTHING AND OUTPUT OF THE DIFFUSION RATE */
  for(i=NSMOOTH+1;i<=ntp-NSMOOTH;i++){
    avedact = avedang = 0;
    for(j=i-NSMOOTH;j<=i+NSMOOTH;j++){
      avedact += fabs(dmaxact[j]);
      avedang += fabs(dmaxang[j]);
    }
    avedact = avedact / (2*NSMOOTH+1);
    avedang = avedang / (2*NSMOOTH+1);   

    if(flag[i] != 0 && avedact > 0 && avedang > 0){ 
      printf("%d %d %lg %lg %lg %lg %lg %lg %lg\n",
	     id[i],flag[i],sema[i],ecc[i],inc[i],ampact[i],
	     (avedact),ampang[i],(avedang));
    } else {
	printf("%d %d %lg %lg %lg %lg %lg %lg %lg\n",
	       id[i],flag[i],sema[i],ecc[i],inc[i],ampact[i],
	       log10(fabs(dmaxact[i])),ampang[i],log10(fabs(dmaxang[i])));
    }
  }

  for(i=ntp-NSMOOTH+1;i<=ntp;i++)
    printf("%d %d %lg %lg %lg %lg %lg %lg %lg\n",
	   id[i],flag[i],sema[i],ecc[i],inc[i],ampact[i],
	   log10(fabs(dmaxact[i])),ampang[i],log10(fabs(dmaxang[i])));
  

  return 1;
}









